clear all
clear mata
graph drop _all
mata: mata set matastrict off, permanently
program drop _all
macro drop _all
matrix drop _all
set more off
set memory 4G
set type double
set matsize 10000

global tab "ci(%9.3f) b(%9.3f) r2(%9.2f) scalar(N_h_l N_h_r) sfmt(%9.0f) nogaps nostar mtitles brackets"

***************************************************************************
************* WHEN DOES REGRESSION DISCONTINUITY DESIGN WORK? *************
***************** EVIDENCE FROM RANDOM ELECTION OUTCOMES ******************
***************************************************************************

* This do-file replicates the analysis in the main text of "When Does Regression
* Discontinuity Design Work? Evidence from Random Election Outcomes" by Ari Hyytinen,
* Jaakko Meriläinen, Tuukka Saarimaa, Otto Toivanen and Janne Tukiainen.

* NB. The data on candidate characteristics are proprietary. Replicating parts of
* Table 1 and columns (2)-(4) of Table 2 would require obtaining these data. 

* Some of the RDD analysis in this paper uses rdrobust package in Stata. For more
* details, see https://sites.google.com/site/rdpackages/rdrobust.

/*
The data we have made available can be used to replicate all figures in the main text and Tables 3 and 4. 
However, only column (1) of Table 2 is replicable, because the other columns use candidate characteristics as controls and these data are proprietary. 
Table 1 uses also mostly these proprietary data. 

Replicating these missing parts of our analysis requires access through the normal application processes of the various registers. 
The overall cost of acquiring the complete data set was roughly 5000 euros for us. 
The data sets are merged via a social security number which uniquely identifies all Finns. 
These information do not require that the data is anonymized and the data will be send to the researchers conditional on signing the appropriate contracts regarding, for example, data security.

The main data consist of candidate level municipal election results for the election years 1996, 2000, 2004, 2008 and 2012. 
These we have made available, but merging with the other register requires the social security number also for these data. 
This data is available to be purchased form the Finnish Ministry of Justice. The contact email is “vaalit@om.fi”. 

The other registers, the contact email and the information content are:
Finnish Tax Authority, verotilastot@vero.fi, income. 
Statistics Finland, tutkijapalvelut@tilastokeskus.fi, education, occupation and socioeconomic status.
Finnish Local Government Pensions Institution, tilastot@keva.fi,municipal employee status. 
*/

global dir "/Users/jaakko/Dropbox/Kuel/CloseElectionsRDD/QE" // set working directory

cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear

********************************************************************************

* Bandwidths provided by the (deprecated) command rdrobust_2014
* rdbwselect_2014 electednextelection vmargin if vmargin!=0, all
* h_CCT .7442886; b_CCT 3.026542 
* h_IK .5404951; b_IK 1.13615
* rdbwselect_2014 electednextelection vmargin if vmargin!=0, all p(2)
* h_CCT 2.089258; b_CCT 5.380058  
* h_IK 1.408483; b_IK 1.494337
* rdbwselect_2014 electednextelection vmargin if vmargin!=0, all p(3)
* h_CCT 3.983958; b_CCT 7.904894 
* h_IK 1.83664; b_IK 1.920773

global h_IK1 = 0.5404951
global h_IK2 = 1.408483
global h_IK3 = 1.83664
global h_CCT1 = 0.7442886
global h_CCT2 = 2.089258
global h_CCT3 = 3.983958
global b_IK1 = 1.13615
global b_IK2 = 1.494337
global b_IK3 = 1.920773
global b_CCT1 = 3.026542
global b_CCT2 = 5.380058
global b_CCT3 = 7.904894

* Adjusted bandwidths
sum electednextelection if vmargin!=0 & electionyear<2012 & vmargin!=.
global h_CCT1_adj = 0.7442886*r(N)^(-1/20)
global h_CCT2_adj = 2.089258*r(N)^(-2/35)
global h_CCT3_adj = 3.983958*r(N)^(-3/54)

********************************************************************************

* Table 1: Covariate balance tests for the lottery sample

* Generating party and municipality vote shares, and a female dummy
bysort munid electionyear: egen municipalityvotes=sum(votes)
gen munvoteshare=100*votes/municipalityvotes // vote share in whole municipality
bysort munid electionyear party: egen partyvotes=sum(votes)
gen partyvoteshare=100*votes/partyvotes // vote share within party
gen female=0
replace female=1 if gender=="N" // female dummy

* Summary statistics
sum munvoteshare partyvoteshare votes female age incumbent if elected==0 & vmargin==0 & electionyear<2012 // Non-elected candidates, lottery sample
sum munvoteshare partyvoteshare votes female age incumbent if elected==1 & vmargin==0 & electionyear<2012 // Elected candidates, lottery sample

* Testing for differences
* t-test allowing clustering at municipality level
foreach x of varlist munvoteshare partyvoteshare votes female age incumbent {
	clttest `x' if electionyear<2012 & vmargin==0, cluster(munid) by(elected)
}

* Testing for differences
* t-test allowing clustering at municipality level
foreach x of varlist munvoteshare partyvoteshare votes female age incumbent {
	ttest `x' if electionyear<2012 & vmargin==0, by(elected)
}

********************************************************************************

* Table 2: Experimental estimates of the personal incumbency advantage

reg electednextelection elected, cluster(munid), if vmargin==0 // clustered standard errors
estimates store model1

reg electednextelection elected if vmargin==0, robust // robust standard errors
estimates store model2

esttab model*, $tab keep(elected)
est clear

********************************************************************************

* Figure 1: Curvature between the forcing variable and the outcome

cd "$dir/Replication material/figures/"

rdplot electednextelection vmargin if abs(vmargin)<=$h_IK1 & vmargin!=0, p(1) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Linear") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1alinear.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK1 & vmargin!=0, p(2) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Quadratic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1aquadratic.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK1 & vmargin!=0, p(3) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Cubic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1acubic.gph, replace

graph combine "figure1alinear.gph" "figure1aquadratic.gph" "figure1acubic.gph", cols(3) graphregion(color(white)) subtitle("Panel A") ycommon
graph save figure1a.gph, replace

rdplot electednextelection vmargin if abs(vmargin)<=$h_IK2 & vmargin!=0, p(2) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Quadratic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1bquadratic.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK2 & vmargin!=0, p(3) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Cubic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1bcubic.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK2 & vmargin!=0, p(4) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Quartic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1bquartic.gph, replace

graph combine "figure1bquadratic.gph" "figure1bcubic.gph" "figure1bquartic.gph", cols(3) graphregion(color(white)) subtitle("Panel B") ycommon
graph save figure1b.gph, replace

rdplot electednextelection vmargin if abs(vmargin)<=$h_IK3 & vmargin!=0, p(3) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Cubic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1ccubic.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK3 & vmargin!=0, p(4) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Quartic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1cquartic.gph, replace
rdplot electednextelection vmargin if abs(vmargin)<=$h_IK3 & vmargin!=0, p(5) binselect(es) graph_options(xline(0, lcolor(bluishgray)) title("") ylabel(, format(%3.2f)) xlabel(, format(%3.2f)) subtitle("Quintic") graphregion(color(white)) legend(off) xtitle(Vote margin (%)) ytitle(Elected t+1))
graph save figure1cquintic.gph, replace

graph combine "figure1ccubic.gph" "figure1cquartic.gph" "figure1cquintic.gph", cols(3) graphregion(color(white)) subtitle("Panel C") ycommon
graph save figure1c.gph, replace

graph combine "figure1a.gph" "figure1b.gph" "figure1c.gph", cols(1) graphregion(color(white)) xsize(12) ysize(16) ycommon
graph save figure1.gph, replace
graph export "Figure 1.eps", as(eps) preview(off) replace

********************************************************************************

* Table 3: Local polynomial RDD estimates

gen weight=. // generating variable for (triangular) weights

* Linear control polynomial, IK(1) and CCT(1) bandwidths
gen Tvmargin = elected*vmargin

quietly {
	foreach c in $h_IK1 $h_CCT1 {
		/*replace weight=1-abs(vmargin/(`c'/2))
		eststo: reg electednextelection elected vmargin Tvmargin [pw=weight], cluster(munid) , if abs(vmargin)<=`c'/2 & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin Tvmargin [pw=weight] if abs(vmargin)<=`c'/2 & vmargin!=0, robust // robust standard errors*/
		replace weight=1-abs(vmargin/`c')
		eststo: reg electednextelection elected vmargin Tvmargin [pw=weight], cluster(munid) , if abs(vmargin)<=`c' & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin Tvmargin [pw=weight] if abs(vmargin)<=`c' & vmargin!=0, robust // robust standard errors
		}
	}
	
esttab, $tab keep(elected)
esttab using "$dir/Replication material/tables/table3.csv", replace scsv $tab keep(elected) nonotes
est clear

* Quadratic control polynomial,  IK(1) and CCT(1) bandwidths
gen vmargin2=vmargin*vmargin
gen Tvmargin2=Tvmargin*Tvmargin

quietly {
	foreach c in $h_IK1 $h_CCT1 {
		replace weight=1-abs(vmargin/(`c'/2))
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight], cluster(munid) , if abs(vmargin)<=`c'/2 & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight] if abs(vmargin)<=`c'/2 & vmargin!=0, robust // robust standard errors
		replace weight=1-abs(vmargin/`c')
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight], cluster(munid) , if abs(vmargin)<=`c' & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight] if abs(vmargin)<=`c' & vmargin!=0, robust // robust standard errors
		}
	}
	
esttab, $tab keep(elected)
esttab using "$dir/Replication material/tables/table3.csv", append scsv $tab keep(elected) nonotes
est clear

* Cubic control polynomial,  IK(1) and CCT(1) bandwidths
gen vmargin3=vmargin2*vmargin
gen Tvmargin3=Tvmargin2*Tvmargin

quietly {
	foreach c in $h_IK1 $h_CCT1 {
		replace weight=1-abs(vmargin/(`c'/2))
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight], cluster(munid) , if abs(vmargin)<=`c'/2 & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight] if abs(vmargin)<=`c'/2 & vmargin!=0, robust // robust standard errors
		replace weight=1-abs(vmargin/`c')
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight], cluster(munid) , if abs(vmargin)<=`c' & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight] if abs(vmargin)<=`c' & vmargin!=0, robust // robust standard errors
		}
	}

esttab, $tab keep(elected)
esttab using "$dir/Replication material/tables/table3.csv", append scsv $tab keep(elected) nonotes
est clear

* Quadratic control polynomial, IK(2) and CCT(2) bandwidths
quietly {
	foreach c in $h_IK2 $h_CCT2 {
		replace weight=1-abs(vmargin/`c')
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight], cluster(munid) , if abs(vmargin)<=`c' & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 Tvmargin Tvmargin2 [pw=weight] if abs(vmargin)<=`c' & vmargin!=0, robust // robust standard errors
		}
	}
	
esttab, $tab keep(elected)
esttab using "$dir/Replication material/tables/table3.csv", append scsv $tab keep(elected) nonotes
est clear

* Cubic control polynomial, IK(3) and CCT(3) bandwidths
quietly {
	foreach c in $h_IK3 $h_CCT3 {
		replace weight=1-abs(vmargin/`c')
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight], cluster(munid) , if abs(vmargin)<=`c' & vmargin!=0 // clustered standard errors
		eststo: reg electednextelection elected vmargin vmargin2 vmargin3 Tvmargin Tvmargin2 Tvmargin3 [pw=weight] if abs(vmargin)<=`c' & vmargin!=0, robust // robust standard errors
		}
	}

esttab, $tab keep(elected)
esttab using "$dir/Replication material/tables/table3.csv", append scsv $tab keep(elected) nonotes
est clear

********************************************************************************

* Figure 2: Conventional RDD estimates using various bandwidths

cd "$dir/Replication material/figures/"

* Linear control polynomial
forvalues i = 10(1)210 {
	replace weight=1-abs(vmargin/(`i'/100))
	reg electednextelection elected vmargin Tvmargin [pw=weight], cluster(munid) , if abs(vmargin)<=`i'/100 & vmargin!=0	
	parmest, saving(linear`i'.dta, replace)	
}

forvalues i = 10(1)210 {
	use linear`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="elected"
	save, replace
}

use linear10.dta, clear

forvalues i = 11(1)210 {
	append using linear`i'.dta
}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0, lcolor(black) lwidth(vthin)) lpattern(dash) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Linear") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK1, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure2linear.gph, replace

* Quadratic control polynomial

cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
gen weight=.
gen Tvmargin = elected*vmargin
gen vmargin2=vmargin*vmargin
gen Tvmargin2=Tvmargin*Tvmargin

cd "$dir/Replication material/figures/"

forvalues i = 10(1)210 {
	replace weight=1-abs(vmargin/(`i'/100))
	reg electednextelection elected vmargin Tvmargin vmargin2 Tvmargin2 [pw=weight], cluster(munid) , if abs(vmargin)<=`i'/100 & vmargin!=0
	parmest, saving(quadratic`i'.dta, replace)
}

forvalues i = 10(1)210 {
	use quadratic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="elected"
	save, replace
}

use quadratic10.dta, clear

forvalues i = 11(1)210 {
	append using quadratic`i'.dta
}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0, lcolor(black) lwidth(vthin)) lpattern(dash) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Quadratic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK2, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure2quadratic.gph, replace

* Cubic control polynomial

cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
gen weight=.
gen Tvmargin = elected*vmargin
gen vmargin2=vmargin*vmargin
gen Tvmargin2=Tvmargin*Tvmargin
gen vmargin3=vmargin2*vmargin
gen Tvmargin3=Tvmargin2*Tvmargin

cd "$dir/Replication material/figures/"

forvalues i = 10(1)210 {
	replace weight=1-abs(vmargin/(`i'/100))
	reg electednextelection elected vmargin Tvmargin vmargin2 Tvmargin2 vmargin3 Tvmargin3 [pw=weight], cluster(munid), if abs(vmargin)<=`i'/100 & vmargin!=0
	parmest, saving(cubic`i'.dta, replace)
	
}

forvalues i = 10(1)210 {

	use cubic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="elected"
	save, replace
	
}

use cubic10.dta, clear

forvalues i = 11(1)210 {
	append using cubic`i'.dta
}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0, lcolor(black) lwidth(vthin)) lpattern(dash) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Cubic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK3, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure2cubic.gph, replace

graph combine figure2linear.gph figure2quadratic.gph figure2cubic.gph, ycommon graphregion(color(white)) cols(3) ysize(3) xsize(9)
graph save figure2.gph, replace
graph export "Figure 2.eps", as(eps) preview(off) replace

********************************************************************************

* Table 4: CCT bias-corrected local polynomial RDD estimates with robust inference

cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear

* Columns (1) and (2)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_IK1) b($b_IK1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_IK1) b($b_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_CCT1) b($b_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_CCT1) b($b_CCT1) vce(cluster munid) // clustered inference
	}

esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", replace scsv $tab keep(Robust) nonotes
est clear

* Columns (3) and (4)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK1) b($b_IK1)  // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK1) b($b_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT1) b($b_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT1) b($b_CCT1) vce(cluster munid) // clustered inference
	}
	
esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (5) and (6)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK1) b($b_IK1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK1) b($b_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT1) b($b_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT1) b($b_CCT1) vce(cluster munid) // clustered inference
	}
	
esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (7) and (8)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_IK1) b($h_IK1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_IK1) b($h_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_CCT1) b($h_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all h($h_CCT1) b($h_CCT1) vce(cluster munid) // clustered inference
	}
	
esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (9) and (10)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK1) b($h_IK1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK1) b($h_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT1) b($h_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT1) b($h_CCT1) vce(cluster munid) // clustered inference
}

esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (11) and (12)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK1) b($h_IK1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK1) b($h_IK1) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT1) b($h_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT1) b($h_CCT1) vce(cluster munid) // clustered inference
	}
	
esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (15) and (16)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK2) b($b_IK2) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_IK2) b($b_IK2) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT2) b($b_CCT1) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(2) h($h_CCT2) b($b_CCT1) vce(cluster munid) // clustered inference
}

esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

* Columns (17) and (18)
quietly {
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK3) b($b_IK3) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_IK3) b($b_IK3) vce(cluster munid) // clustered inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT3) b($b_CCT3) // robust inference
	eststo: rdrobust electednextelection vmargin if vmargin!=0, all p(3) h($h_CCT3) b($b_CCT3) vce(cluster munid) // clustered inference
}

esttab, $tab keep(Robust)
esttab using "$dir/Replication material/tables/table4.csv", append scsv $tab keep(Robust) nonotes
est clear

********************************************************************************

* Figure 3: Bias-corrected RDD estimates, fixed bias bandwidth

* Linear control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b($b_IK1)
	parmest, saving(figure3linear`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure3linear`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace	
	}

use figure3linear10.dta, clear

forvalues i = 11(1)210 {
	append using figure3linear`i'.dta	
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0) lpattern(dash) lcolor(gray) lwidth(med) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))  yline(0, lcolor(black) lwidth(vthin)) subtitle("Linear") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK1, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(med) lcolor(black) msymbol(none))
graph save figure3linear.gph, replace

* Quadratic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b($b_IK2) p(2)
	parmest, saving(figure3quadratic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure3quadratic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure3quadratic10.dta, clear

forvalues i = 11(1)210 {
	append using figure3quadratic`i'.dta
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0) lpattern(dash) lcolor(gray) lwidth(med) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))  yline(0, lcolor(black) lwidth(vthin))   subtitle("Quadratic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK2, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(med) lcolor(black) msymbol(none))
graph save figure3quadratic.gph, replace

* Cubic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b($b_IK3) p(3)
	parmest, saving(figure3cubic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure3cubic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure3cubic10.dta, clear

forvalues i = 11(1)210 {
	append using figure3cubic`i'.dta
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, lpattern(dash) lcolor(gray) lwidth(med) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   yline(0, lcolor(black) lwidth(vthin)) subtitle("Cubic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK3, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(med) lcolor(black) msymbol(none))
graph save figure3cubic.gph, replace

graph combine figure3linear.gph figure3quadratic.gph figure3cubic.gph, ycommon graphregion(color(white)) cols(3) ysize(3) xsize(9)
graph save figure3.gph, replace
graph export "Figure 3.eps", as(eps) preview(off) replace

********************************************************************************

* Figure 4: Bias-corrected RDD results, both bandwidths vary

* Linear control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=2.13346211035693*`c'/100
	local k=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`k') b(`h')
	parmest, saving(figure4linear`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure4linear`i'.dta, clear
	gen bandwidth = `i'/100
	gen bandwidth2 = 2.13346211035693*`i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure4linear10.dta, clear

forvalues i = 11(1)210 {
	append using figure4linear`i'.dta
	}

sum bandwidth
local min=r(min)
local max=r(max)
local jump=r(min)*2
local xmin = r(min)
local xmax = r(max)

sum bandwidth2
local xmin2=r(min)
local tick=`xmin2'*2
local xmax2=r(max)

twoway (rline min95 max95 bandwidth, ylabel(, format(%3.2f)) lpattern(dash) lcolor(gray) yline(0, lcolor(black) lwidth(vthin)) lwidth(med) xaxis(1) xlabel(`xmin'(`jump')`xmax', axis(1) format(%3.2f)) subtitle("Linear") legend(off) xtitle("Bandwidth", axis(1)) ytitle(Estimated effect) graphregion(color(white)) xline($h_IK1, lcolor(cranberry))) (rline min95 max95 bandwidth2, lpattern(dash) lcolor(gray) lwidth(med) xaxis(2) xlabel(`xmin2'(`tick')`xmax2', axis(2) format(%3.2f)) xtitle("Pilot bandwidth", axis(2)) ) (scatter estimate bandwidth, connect(direct) lwidth(med) lcolor(black) msymbol(none))
graph save figure4linear.gph, replace

* Quadratic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=1.060217003708489*`c'/100
	local k=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`k') b(`h') p(2)
	parmest, saving(figure4quadratic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure4quadratic`i'.dta, clear
	gen bandwidth = `i'/100
	gen bandwidth2 = 1.060217003708489*`i'/100
	drop if parm!="Robust"
	save, replace	
	}

use figure4quadratic10.dta, clear

forvalues i = 11(1)210 {
	append using figure4quadratic`i'.dta	
	}

sum bandwidth
local min=r(min)
local max=r(max)
local jump=r(min)*2
local xmin = r(min)
local xmax = r(max)

sum bandwidth2
local xmin2=r(min)
local tick=`xmin2'*2
local xmax2=r(max)

twoway (rline min95 max95 bandwidth, ylabel(, format(%3.2f)) lpattern(dash) yline(0, lcolor(black) lwidth(vthin)) lcolor(gray) lwidth(medium) xaxis(1) xlabel(`xmin'(`jump')`xmax', axis(1) format(%3.2f)) subtitle("Quadratic") legend(off) xtitle("Bandwidth", axis(1)) ytitle(Estimated effect) graphregion(color(white)) xline($h_IK2, lcolor(cranberry))) (rline min95 max95 bandwidth2, lpattern(dash) lcolor(gray) lwidth(medium) xaxis(2) xlabel(`xmin2'(`tick')`xmax2', axis(2) format(%3.2f)) xtitle("Pilot bandwidth", axis(2)) ) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure4quadratic.gph, replace

* Cubic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	local k=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`k') b(`h') p(3)
	parmest, saving(figure4cubic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure4cubic`i'.dta, clear
	gen bandwidth = `i'/100
	gen bandwidth2 = 1.045790483533045*`i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure4cubic10.dta, clear

forvalues i = 11(1)210 {
	append using figure4cubic`i'.dta
	}

sum bandwidth
local min=r(min)
local max=r(max)
local jump=r(min)*2
local xmin = r(min)
local xmax = r(max)

sum bandwidth2
local xmin2=r(min)
local tick=`xmin2'*2
local xmax2=r(max)

twoway (rline min95 max95 bandwidth if bandwidth>=0.2, ylabel(, format(%3.2f)) yline(0, lcolor(black) lwidth(vthin)) lpattern(dash) lcolor(gray) lwidth(medium) xaxis(1) xlabel(`xmin'(`jump')`xmax', axis(1) format(%3.2f)) subtitle("Cubic") legend(off) xtitle("Bandwidth", axis(1)) ytitle(Estimated effect) graphregion(color(white)) xline($h_IK3, lcolor(cranberry))) (rline min95 max95 bandwidth2 if bandwidth>=0.2, lpattern(dash) lcolor(gray) lwidth(medium) xaxis(2) xlabel(`xmin2'(`tick')`xmax2', axis(2) format(%3.2f)) xtitle("Pilot bandwidth", axis(2)) ) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure4cubic.gph, replace

graph combine figure4linear.gph figure4quadratic.gph figure4cubic.gph, graphregion(color(white)) cols(3) ysize(3) xsize(9) ycommon
graph save figure4.gph, replace
graph export "Figure 4.eps", as(eps) preview(off) replace

********************************************************************************

* Figure 5: Bias-corrected RDD results, bandwidths equal

* Linear control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b(`h')
	parmest, saving(figure5linear`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure5linear`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure5linear10.dta, clear

forvalues i = 11(1)210 {
	append using figure5linear`i'.dta
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, yline(0, lcolor(black) lwidth(vthin)) xline($h_CCT1, lwidth(medium) lcolor(cranberry) lpattern(longdash)) xline($h_CCT1_adj, lwidth(medium) lcolor(cranberry) lpattern(shortdash)) lpattern(dash) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Linear") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK1, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure5linear.gph, replace

* Quadratic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b(`h') p(2)
	parmest, saving(figure5quadratic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure5quadratic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure5quadratic10.dta, clear

forvalues i = 11(1)210 {
	append using figure5quadratic`i'.dta
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth, lpattern(dash) yline(0, lcolor(black) lwidth(vthin)) xline($h_CCT2, lwidth(medium) lcolor(cranberry) lpattern(longdash)) xline($h_CCT2_adj, lwidth(medium) lcolor(cranberry) lpattern(shortdash)) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Quadratic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK2, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure5quadratic.gph, replace

* Cubic control polynomial
cd "$dir/Replication material/data/"
use "HMSTT_data_22082017.dta", clear
cd "$dir/Replication material/figures/"

forvalues c = 10(1)210 {
	local h=`c'/100
	rdrobust electednextelection vmargin if vmargin!=0, all h(`h') b(`h') p(3)
	parmest, saving(figure5cubic`c'.dta, replace)
	}

forvalues i = 10(1)210 {
	use figure5cubic`i'.dta, clear
	gen bandwidth = `i'/100
	drop if parm!="Robust"
	save, replace
	}

use figure5cubic10.dta, clear

forvalues i = 11(1)210 {
	append using figure5cubic`i'.dta
	}

sum bandwidth
local xmin = r(min)
local tick=`xmin'*2
local xmax = r(max)

twoway (rline min95 max95 bandwidth if bandwidth>=0.2, yline(0, lcolor(black) lwidth(vthin)) xline($h_CCT3_adj, lwidth(medium) lcolor(cranberry) lpattern(shortdash)) lpattern(dash) lcolor(gray) lwidth(medium) xlabel(`xmin'(`tick')`xmax', format(%3.2f)) ylabel(, format(%3.2f))   subtitle("Cubic") legend(off) xtitle("Bandwidth") ytitle(Estimated effect) graphregion(color(white)) xline($h_IK3, lcolor(cranberry))) (scatter estimate bandwidth, connect(direct) lwidth(medium) lcolor(black) msymbol(none))
graph save figure5cubic.gph, replace

graph combine figure5linear.gph figure5quadratic.gph figure5cubic.gph, graphregion(color(white)) cols(3) ysize(3) xsize(9) ycommon
graph save figure5.gph, replace
graph export "Figure 5.eps", as(eps) preview(off) replace
